Pareidoscope
============

The Pareidoscope is a collection of tools for determining the
association between arbitrary linguistic structures, e.g. between words
(collocations), between words and structures (collostructions) or
between structures.

More detailed documentation is available `here
<https://github.com/tsproisl/Pareidoscope>`__.
